@@ -180,6 +180,7 @@ NULL
 ces <- function(prices,shares,margins,  diversions,
                 ownerPre,ownerPost,
                 normIndex=ifelse(sum(shares)<1,NA,1),
+                mktElast=NA_real_,
                 insideSize = NA_real_,
                 mcDelta=rep(0,length(prices)),
                 subset=rep(TRUE,length(prices)),
@@ -200,6 +201,7 @@ ces <- function(prices,shares,margins,  diversions,
                 diversion=diversions,
                 normIndex=normIndex,
                 mcDelta=mcDelta,
+                mktElast=mktElast,
                 insideSize = insideSize,
                 subset=subset,
                 priceOutside=priceOutside,
