@@ -22,6 +22,8 @@
 #' @param object An instance of one of the classes listed above.
 #' @param levels If TRUE, report results in levels. If FALSE, report results in percents. Default is FALSE.
 #' @param market If TRUE, calculates (post-merger) share-weighted average of metric. Default is FALSE.
+#' @param index If "paasche",calculates market-wide price changes using post-merger predicted shares. If  "laspeyres", 
+#' calculates price index using pre-merger shares. Default is "paasche".
 #' @param isMax If TRUE, uses numerical derivatives to determine if
 #' equilibrium price vector is a local maximum. Default is FALSE.
 #' @param subset A vector of length k where each element equals TRUE if
@@ -30,7 +32,7 @@
 #' length k vector of TRUE.
 #' @param exAnte If \sQuote{exAnte} equals TRUE then the
 #' \emph{ex ante} expected result for each firm is produced, while FALSE produces the
-#' expected result conditional on each firm winning the auction. Default is FALSE.
+#' expected result conditional on each firm winning the auction. Default is FALSE, unless \sQuote{market} is TRUE.
 #' @param ... Additional values that may be used to change the default values of the non-linear
 #' equation solver.
 #'
@@ -40,7 +42,7 @@ NULL
 
 setGeneric (
   name= "calcPriceDelta",
-  def=function(object,...){standardGeneric("calcPriceDelta")}
+  def=function(object,levels = FALSE, market = FALSE,...){standardGeneric("calcPriceDelta")}
 )
 
 ## Method to compute price changes
@@ -49,26 +51,33 @@ setGeneric (
 setMethod(
   f= "calcPriceDelta",
   signature= "Antitrust",
-  definition=function(object, levels = FALSE, market = FALSE, ...  ){
+  definition=function(object, levels = FALSE, market = FALSE, index=c("paasche","laspeyres"), ...  ){
 
+    index <- match.arg(index)
+    
     pricePre  <- object@pricePre
     pricePost <- object@pricePost
 
+    
     if(levels){priceDelta <- pricePost - pricePre}
     else{priceDelta <- pricePost/pricePre - 1}
     #names(priceDelta) <- object@labels
 
     if(market){
       
-      sharesPre <- calcShares(object, preMerger=TRUE,...)
+      sharesPre <- calcShares(object, preMerger=TRUE,revenue=FALSE,...)
       sharesPre <- sharesPre/sum(sharesPre,na.rm=TRUE)
       
+      sharesPost <- calcShares(object, preMerger=FALSE,revenue=FALSE,...)
+      sharesPost <- sharesPost/sum(sharesPost,revenue=FALSE,na.rm=TRUE)
       
-      sharesPost <- calcShares(object, preMerger=FALSE,...)
-      sharesPost <- sharesPost/sum(sharesPost,na.rm=TRUE)
+      
+      if(index=="paasche")  priceDelta <- sum(sharesPost*pricePost)/sum(sharesPost*pricePre) - 1
+      else if (index=="laspeyres")  priceDelta <- sum(sharesPre*pricePost)/sum(sharesPre*pricePre) - 1
+      
+      
       
       
-      priceDelta <- sum(pricePost*sharesPost,na.rm=TRUE)/ sum(pricePre*sharesPre,na.rm=TRUE) - 1
     }
 
     return(priceDelta)
@@ -76,6 +85,18 @@ setMethod(
   }
 )
 
+#'@rdname PriceDelta-Methods
+#'@export
+setMethod(
+  f= "calcPriceDelta",
+  signature= "Cournot",
+  definition=function(object, levels = FALSE, market=TRUE, ...  ){
+    
+    callNextMethod()
+    
+  }
+)
+
 #'@rdname PriceDelta-Methods
 #'@export
 setMethod(
@@ -158,9 +179,17 @@ setMethod(
 setMethod(
   f= "calcPriceDelta",
   signature= "AIDS",
-  definition=function(object,isMax=FALSE,levels=FALSE,subset,market=FALSE,...){
+  definition=function(object,isMax=FALSE,levels=FALSE,subset,market=FALSE, index=c("paasche","laspeyres"),...){
 
-    if(market) return(sum(object@priceDelta * calcShares(object, preMerger = FALSE),na.rm=TRUE))
+    index <- match.arg(index)
+    
+    if(market){
+      
+      if(index=="paasche") shares <-  calcShares(object, preMerger = FALSE)
+      else{shares <-  calcShares(object, preMerger = TRUE)}
+    
+      return(sum(object@priceDelta * shares,na.rm=TRUE))
+           }
 
     ownerPost <- object@ownerPost
 
@@ -229,12 +258,19 @@ setMethod(
 setMethod(
   f= "calcPriceDelta",
   signature= "Auction2ndLogit",
-  definition=function(object,exAnte=FALSE,levels=TRUE, market=FALSE){
+  definition=function(object,levels=TRUE, market=FALSE,exAnte=ifelse(market,TRUE,FALSE),...){
 
+    if(!levels){
+      result <- callNextMethod()
+      return(result)
+    }
+    
     subset <- object@subset
 
     mcDelta <- object@mcDelta
 
+
+    
     if(exAnte){
       sharesPost <- calcShares(object, preMerger=FALSE)
       mcDelta <- mcDelta*sharesPost
@@ -243,9 +279,12 @@ setMethod(
     result <- calcMargins(object, preMerger=FALSE,exAnte=exAnte) + mcDelta -
       calcMargins(object, preMerger=TRUE,exAnte=exAnte)
 
-    if(!levels){result <- result/calcPrices(object,preMerger = TRUE, exAnte = exAnte )}
+    if(market) result <- sum(result,na.rm=TRUE)
+    
+ 
 
-    names(result) <- object@labels
+    if(!market) names(result) <- object@labels
+    
     return(result)
   }
 )
